function [IE,T] = histeq(I,m)
% Equalizzazione dell'istogramma di un'imagine
% [ie, t]=histeq(I, m)
% I: immagine
% m: parametro di equalizzazione
% IE : immagine equalizzata
% T: tavola dei colori
% per immagini su 255 toni di grigio 

bins=[0:255];
I=double(I);
h=hist(I(:),bins);
    
% calcolo di T 
hsum=cumsum(h.^m);
T=(hsum/hsum(end))*256;
    
% Calcola l'immagine finale con l'interpolazione
IEv=interp1(bins, T, I(:), 'nearest' );
IE=reshape(IEv, size(I));    
